# TermMenu

This is a little Python project that I wanted to do for some time.

The idea is that you should be able to make a terminal menu (below) easily and compactly.

```text
Choose one:
0. Start game
1. Settings
2. And more
> {User input here}
```

## Documentation

Read the documentation on [ReadTheDocs](https://pytermmenu.readthedocs.io/en/latest/index.html).

## Contributing

You are welcome to contribute.